# -*- coding: utf-8 -*-
"""
rsCase is a simple python package implemented in Rust for string case translation.
"""

__author__ = "Sondre Lillebø Gundersen"
__version__ = "1.1.1"  # Remember to change cargo.toml
